@@ -3,10 +3,12 @@
 # Generates stencil code. This replaces the macros in stencil-et.h,
 # which make it impossible to debug the generated code.
 
+from __future__ import print_function
+
 import sys
 
 os=open(sys.argv[1],'w')
-print "Generating file %s"%sys.argv[1]
+print("Generating file %s"%sys.argv[1])
 
 def BZ_ET_STENCIL_REDIRECT(name):
     stub="""
@@ -14,12 +16,12 @@ def BZ_ET_STENCIL_REDIRECT(name):
 
 /* Explicit operators for arrays for stencil name. */
 template<typename T, int N>						
-inline _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result> >
+inline _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result> >
 #name#(const Array<T,N>& d1)
 { return #name#(d1.wrap()); }
 
 template<typename T, int N>
-inline _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result> >
+inline _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result> >
 #name#(Array<T,N>& d1)
 { return #name#(d1.wrap()); }
 """
@@ -122,7 +124,7 @@ def BZ_ET_STENCIL(name, result, etresult, MINB, MAXB):
       return r;								
     }									
 									
-    void prettyPrint(BZ_STD_SCOPE(string) &str,				
+    void prettyPrint(std::string &str,				
 		     prettyPrintFormat& format) const			
     {									
       str += "#name# (stencil)";						
@@ -168,20 +170,20 @@ def BZ_ET_STENCIL(name, result, etresult, MINB, MAXB):
   };									
   /* generate an ET object from an expression */			
   template<typename T1>							
-  inline _bz_ArrayExpr<#name#_et<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result, #etresult#> > 
-  #name#(const BZ_BLITZ_SCOPE(ETBase)<T1>& d1)				
+  inline _bz_ArrayExpr<#name#_et<typename blitz::asExpr<T1>::T_expr::T_range_result, #etresult#> > 
+  #name#(const blitz::ETBase<T1>& d1)				
   {									
-    return _bz_ArrayExpr<#name#_et<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result, #etresult#> > 
-      (BZ_BLITZ_SCOPE(asExpr)<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),MINB, MAXB))); 
+    return _bz_ArrayExpr<#name#_et<typename blitz::asExpr<T1>::T_expr::T_range_result, #etresult#> > 
+      (blitz::asExpr<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),MINB, MAXB))); 
   }									
   /* redirect calls with bare arrays to the main function */		
   template<typename T, int N>						
-  inline _bz_ArrayExpr<#name#_et<typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result, #result#> > 
+  inline _bz_ArrayExpr<#name#_et<typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result, #result#> > 
   #name#(const Array<T,N>& d1)						
   { return #name#(d1.wrap()); }						
 									
   template<typename T, int N>						
-  inline _bz_ArrayExpr<#name#_et<typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result, #result#> > 
+  inline _bz_ArrayExpr<#name#_et<typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result, #result#> > 
   #name#(Array<T,N>& d1)							
    { return #name#(d1.wrap()); }"""
     os.write(stub.replace("#name#",name).replace("#result#",result).replace("#etresult#",etresult).replace("MINB",str(MINB)).replace("MAXB",str(MAXB)))
@@ -284,7 +286,7 @@ public:
     return r;								
   }									
 									
-  void prettyPrint(BZ_STD_SCOPE(string) &str,				
+  void prettyPrint(std::string &str,				
 		   prettyPrintFormat& format) const			
   {									
     str += "name (stencil)";						
@@ -328,55 +330,55 @@ public:
 									
 /* create ET object from application to expression */			
 template<typename T1, typename T2>					
-inline _bz_ArrayExpr<#name#_et2<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result, typename BZ_BLITZ_SCOPE(asExpr)<T2>::T_expr::T_range_result, #etresult#> > 
-#name#(const BZ_BLITZ_SCOPE(ETBase)<T1>& d1,				
-     const BZ_BLITZ_SCOPE(ETBase)<T2>& d2)				
+inline _bz_ArrayExpr<#name#_et2<typename blitz::asExpr<T1>::T_expr::T_range_result, typename blitz::asExpr<T2>::T_expr::T_range_result, #etresult#> > 
+#name#(const blitz::ETBase<T1>& d1,				
+     const blitz::ETBase<T2>& d2)				
 {									
-  return _bz_ArrayExpr<#name#_et2<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result, typename BZ_BLITZ_SCOPE(asExpr)<T2>::T_expr::T_range_result, #etresult#> > 
-    (BZ_BLITZ_SCOPE(asExpr)<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),MINB, MAXB)), 
-     BZ_BLITZ_SCOPE(asExpr)<T2>::getExpr(d2.unwrap())(_bz_shrinkDomain(d2.unwrap().domain(),MINB, MAXB))); 
+  return _bz_ArrayExpr<#name#_et2<typename blitz::asExpr<T1>::T_expr::T_range_result, typename blitz::asExpr<T2>::T_expr::T_range_result, #etresult#> > 
+    (blitz::asExpr<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),MINB, MAXB)), 
+     blitz::asExpr<T2>::getExpr(d2.unwrap())(_bz_shrinkDomain(d2.unwrap().domain(),MINB, MAXB))); 
 }									
 /* matches to calls involving bare arrays (this is very annoying	
    because we have to exactly match every possible call combination	
    to ensure that this matches instead of the operator in		
    stencilops.h) */							
 template<typename T1, typename T2, int N2>				
-inline _bz_ArrayExpr<#name#_et2<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result, typename BZ_BLITZ_SCOPE(asExpr)<Array<T2,N2> >::T_expr::T_range_result, #result#> > 
-#name#(const BZ_BLITZ_SCOPE(ETBase)<T1>& d1, Array<T2,N2>& d2)		
+inline _bz_ArrayExpr<#name#_et2<typename blitz::asExpr<T1>::T_expr::T_range_result, typename blitz::asExpr<Array<T2,N2> >::T_expr::T_range_result, #result#> > 
+#name#(const blitz::ETBase<T1>& d1, Array<T2,N2>& d2)		
 { return #name#(d1.wrap(), d2.wrap()); }				
 									
 template<typename T1, typename T2, int N2>				
-inline _bz_ArrayExpr<#name#_et2<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result, typename BZ_BLITZ_SCOPE(asExpr)<Array<T2,N2> >::T_expr::T_range_result, #result#> > 
-#name#(const BZ_BLITZ_SCOPE(ETBase)<T1>& d1, const Array<T2,N2>& d2)	
+inline _bz_ArrayExpr<#name#_et2<typename blitz::asExpr<T1>::T_expr::T_range_result, typename blitz::asExpr<Array<T2,N2> >::T_expr::T_range_result, #result#> > 
+#name#(const blitz::ETBase<T1>& d1, const Array<T2,N2>& d2)	
 { return #name#(d1.wrap(), d2.wrap()); }				
 									
 template<typename T1, int N1, typename T2>				
-inline _bz_ArrayExpr<#name#_et2<typename BZ_BLITZ_SCOPE(asExpr)<Array<T1,N1> >::T_expr::T_range_result, typename BZ_BLITZ_SCOPE(asExpr)<T2>::T_expr::T_range_result, #result#> > 
-#name#(Array<T1,N1>& d1, const BZ_BLITZ_SCOPE(ETBase)<T2>& d2)		
+inline _bz_ArrayExpr<#name#_et2<typename blitz::asExpr<Array<T1,N1> >::T_expr::T_range_result, typename blitz::asExpr<T2>::T_expr::T_range_result, #result#> > 
+#name#(Array<T1,N1>& d1, const blitz::ETBase<T2>& d2)		
 { return #name#(d1.wrap(), d2.wrap()); }				
 									
 template<typename T1, int N1, typename T2>				
-inline _bz_ArrayExpr<#name#_et2<typename BZ_BLITZ_SCOPE(asExpr)<Array<T1,N1> >::T_expr::T_range_result, typename BZ_BLITZ_SCOPE(asExpr)<T2>::T_expr::T_range_result, #result#> > 
-#name#(const Array<T1,N1>& d1, const BZ_BLITZ_SCOPE(ETBase)<T2>& d2)	
+inline _bz_ArrayExpr<#name#_et2<typename blitz::asExpr<Array<T1,N1> >::T_expr::T_range_result, typename blitz::asExpr<T2>::T_expr::T_range_result, #result#> > 
+#name#(const Array<T1,N1>& d1, const blitz::ETBase<T2>& d2)	
 { return #name#(d1.wrap(), d2.wrap()); }				
 									
 template<typename T1, int N1, typename T2, int N2>			
-inline _bz_ArrayExpr<#name#_et2<typename BZ_BLITZ_SCOPE(asExpr)<Array<T1,N1> >::T_expr::T_range_result, typename BZ_BLITZ_SCOPE(asExpr)<Array<T2,N2> >::T_expr::T_range_result, #result#> > 
+inline _bz_ArrayExpr<#name#_et2<typename blitz::asExpr<Array<T1,N1> >::T_expr::T_range_result, typename blitz::asExpr<Array<T2,N2> >::T_expr::T_range_result, #result#> > 
 #name#(const Array<T1,N1>& d1, Array<T2,N2>& d2)				
 { return #name#(d1.wrap(), d2.wrap()); }				
 									
 template<typename T1, int N1, typename T2, int N2>			
-inline _bz_ArrayExpr<#name#_et2<typename BZ_BLITZ_SCOPE(asExpr)<Array<T1,N1> >::T_expr::T_range_result, typename BZ_BLITZ_SCOPE(asExpr)<Array<T2,N2> >::T_expr::T_range_result, #result#> > 
+inline _bz_ArrayExpr<#name#_et2<typename blitz::asExpr<Array<T1,N1> >::T_expr::T_range_result, typename blitz::asExpr<Array<T2,N2> >::T_expr::T_range_result, #result#> > 
 #name#(Array<T1,N1>& d1, const Array<T2,N2>& d2)			
 { return #name#(d1.wrap(), d2.wrap()); }				
   									
 template<typename T, int N>						
-inline _bz_ArrayExpr<#name#_et2<typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result, typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result, #result#> > 
+inline _bz_ArrayExpr<#name#_et2<typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result, typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result, #result#> > 
 #name#(Array<T,N>& d1, Array<T,N>& d2)					
 { return #name#(d1.wrap(), d2.wrap()); }				
 									
 template<typename T, int N>						
-inline _bz_ArrayExpr<#name#_et2<typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result, typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result, #result#> > 
+inline _bz_ArrayExpr<#name#_et2<typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result, typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result, #result#> > 
 #name#(const Array<T,N>& d1, const Array<T,N>& d2)			
 { return #name#(d1.wrap(), d2.wrap()); }"""
     os.write(stub.replace("#name#",name).replace("#result#",result).replace("#etresult#",etresult).replace("MINB",str(MINB)).replace("MAXB",str(MAXB)))
@@ -469,7 +471,7 @@ public:
     return r;							
   }									
 									 
-  void prettyPrint(BZ_STD_SCOPE(string) &str,			
+  void prettyPrint(std::string &str,			
 		   prettyPrintFormat& format) const			
   {									
     str += "name (stencil)";						
@@ -510,11 +512,11 @@ public:
 };									
 /* create ET from application to expression */			
 template<typename T1>						
-inline _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> > 
-#name#(const BZ_BLITZ_SCOPE(ETBase)<T1>& d1)				
+inline _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<T1>::T_expr::T_range_result> > 
+#name#(const blitz::ETBase<T1>& d1)				
 {									
-  return _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> >	
-    (BZ_BLITZ_SCOPE(asExpr)<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),MINB, MAXB))); 
+  return _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<T1>::T_expr::T_range_result> >	
+    (blitz::asExpr<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),MINB, MAXB))); 
 }								
 """
     os.write(stub.replace("#name#",name).replace("result_rank",str(result_rank)).replace("MINB",str(MINB)).replace("MAXB",str(MAXB)))
@@ -608,7 +610,7 @@ public:
     return r;								
   }									
 									 
-  void prettyPrint(BZ_STD_SCOPE(string) &str,				
+  void prettyPrint(std::string &str,				
 		   prettyPrintFormat& format) const			
   {									
     str += "name (stencil)";						
@@ -649,11 +651,11 @@ public:
 };									
 /* create ET from application to expression */				
 template<typename T1>							
-inline _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> >	
-#name#(const BZ_BLITZ_SCOPE(ETBase)<T1>& d1)				
+inline _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<T1>::T_expr::T_range_result> >	
+#name#(const blitz::ETBase<T1>& d1)				
 {									
-  return _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> >	
-    (BZ_BLITZ_SCOPE(asExpr)<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),MINB, MAXB))); 
+  return _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<T1>::T_expr::T_range_result> >	
+    (blitz::asExpr<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),MINB, MAXB))); 
 }									
 """
     os.write(stub.replace("#name#",name).replace("result_rank",str(result_rank)).replace("MINB",str(MINB)).replace("MAXB",str(MAXB)))
@@ -746,7 +748,7 @@ public:
     return r;								
   }									
 									
-  void prettyPrint(BZ_STD_SCOPE(string) &str,				
+  void prettyPrint(std::string &str,				
 		   prettyPrintFormat& format) const			
   {									
     str += "name (stencil)";						
@@ -787,11 +789,11 @@ public:
 };									
 /* create ET from application to expression */			
 template<typename T1>							
-inline _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> >	
-#name#(const BZ_BLITZ_SCOPE(ETBase)<T1>& d1)				
+inline _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<T1>::T_expr::T_range_result> >	
+#name#(const blitz::ETBase<T1>& d1)				
 {									
-  return _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> >	
-    (BZ_BLITZ_SCOPE(asExpr)<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),MINB, MAXB))); 
+  return _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<T1>::T_expr::T_range_result> >	
+    (blitz::asExpr<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),MINB, MAXB))); 
 }									
 """
     os.write(stub.replace("#name#",name).replace("MINB",str(MINB)).replace("MAXB",str(MAXB)))
@@ -889,7 +891,7 @@ public:
     return r;								
   }									
 									
-  void prettyPrint(BZ_STD_SCOPE(string) &str,				
+  void prettyPrint(std::string &str,				
 		   prettyPrintFormat& format) const			
   {									
     str += "name (stencil)";						
@@ -933,21 +935,21 @@ private:
 };									
 /* create ET from application to expression */				
 template<typename T1>							
-inline _bz_ArrayExpr<#name#_et<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> >	
-#name#(const BZ_BLITZ_SCOPE(ETBase)<T1>& d1, int dim)			
+inline _bz_ArrayExpr<#name#_et<typename blitz::asExpr<T1>::T_expr::T_range_result> >	
+#name#(const blitz::ETBase<T1>& d1, int dim)			
 {									
-  TinyVector<int, BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::rank_> minb(0), maxb(0); 
+  TinyVector<int, blitz::asExpr<T1>::T_expr::rank_> minb(0), maxb(0); 
   minb[dim]=MINB; maxb[dim]=MAXB;					
-  return _bz_ArrayExpr<#name#_et<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> >	
-    (BZ_BLITZ_SCOPE(asExpr)<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),minb, maxb)), dim); 
+  return _bz_ArrayExpr<#name#_et<typename blitz::asExpr<T1>::T_expr::T_range_result> >	
+    (blitz::asExpr<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),minb, maxb)), dim); 
 }									
 /* forward operations on arrays to main function */			
 template<typename T, int N>						
-inline _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result> > 
+inline _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result> > 
 #name#(const Array<T,N>& d1, int dim)					
 { return #name#(d1.wrap(), dim); }					
 template<typename T, int N>						
-inline _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result> > 
+inline _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result> > 
 #name#(Array<T,N>& d1, int dim)						
 { return #name#(d1.wrap(), dim); }
 """
@@ -1041,7 +1043,7 @@ public:
     return r;								
   }									
 									
-  void prettyPrint(BZ_STD_SCOPE(string) &str,				
+  void prettyPrint(std::string &str,				
 		   prettyPrintFormat& format) const			
   {									
     str += "name (stencil)";						
@@ -1086,22 +1088,22 @@ private:
 };									
 /* create ET from application to expression */			
 template<typename T1>							
-inline _bz_ArrayExpr<#name#_et_multi<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> >	
-#name#(const BZ_BLITZ_SCOPE(ETBase)<T1>& d1, int comp, int dim)		
+inline _bz_ArrayExpr<#name#_et_multi<typename blitz::asExpr<T1>::T_expr::T_range_result> >	
+#name#(const blitz::ETBase<T1>& d1, int comp, int dim)		
 {									
-  TinyVector<int, BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::rank_> minb(0), maxb(0);	
+  TinyVector<int, blitz::asExpr<T1>::T_expr::rank_> minb(0), maxb(0);	
   minb[dim]=MINB; maxb[dim]=MAXB;					
-  return _bz_ArrayExpr<#name#_et_multi<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> > 
-    (BZ_BLITZ_SCOPE(asExpr)<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),minb, maxb)), comp, dim); 
+  return _bz_ArrayExpr<#name#_et_multi<typename blitz::asExpr<T1>::T_expr::T_range_result> > 
+    (blitz::asExpr<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),minb, maxb)), comp, dim); 
 }									
 /* forward operations on arrays to main function */			
 template<typename T, int N>						
-inline _bz_ArrayExpr<#name#_et_multi<_bz_typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result> > 
+inline _bz_ArrayExpr<#name#_et_multi<_bz_typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result> > 
 #name#(const Array<T,N>& d1, int comp, int dim)				
 { return #name#(d1.wrap(), comp, dim); }				
 									
 template<typename T, int N>						
-inline _bz_ArrayExpr<#name#_et_multi<_bz_typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result> > 
+inline _bz_ArrayExpr<#name#_et_multi<_bz_typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result> > 
 #name#(Array<T,N>& d1, int comp, int dim)				
 { return #name#(d1.wrap(), comp, dim); }
 """
@@ -1202,7 +1204,7 @@ public:
     return r;								
   }									
 									
-  void prettyPrint(BZ_STD_SCOPE(string) &str,				
+  void prettyPrint(std::string &str,				
 		   prettyPrintFormat& format) const			
   {									
     str += "name (stencil)";						
@@ -1247,23 +1249,23 @@ private:
  									
 /* create ET from application to expression */
 template<typename T1>							
-inline _bz_ArrayExpr<#name#_et<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> >	
-#name#(const BZ_BLITZ_SCOPE(ETBase)<T1>& d1, int dim1, int dim2)		
+inline _bz_ArrayExpr<#name#_et<typename blitz::asExpr<T1>::T_expr::T_range_result> >	
+#name#(const blitz::ETBase<T1>& d1, int dim1, int dim2)		
 {									
-  TinyVector<int, BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::rank_> minb(0), maxb(0);	
+  TinyVector<int, blitz::asExpr<T1>::T_expr::rank_> minb(0), maxb(0);	
   minb[dim1]=MINB1; maxb[dim1]=MAXB1;					
   minb[dim2]=MINB2; maxb[dim2]=MAXB2;					
-  return _bz_ArrayExpr<#name#_et<typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_range_result> >	
-    (BZ_BLITZ_SCOPE(asExpr)<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),minb, maxb)), dim1, dim2); 
+  return _bz_ArrayExpr<#name#_et<typename blitz::asExpr<T1>::T_expr::T_range_result> >	
+    (blitz::asExpr<T1>::getExpr(d1.unwrap())(_bz_shrinkDomain(d1.unwrap().domain(),minb, maxb)), dim1, dim2); 
 }									
 /* forward operations on arrays to main function */			
 template<typename T, int N>						
-inline _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result> > 
+inline _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result> > 
 #name#(const Array<T,N>& d1, int dim1, int dim2)			
 { return #name#(d1.wrap(), dim1, dim2); }				
 									
 template<typename T, int N>						
-inline _bz_ArrayExpr<#name#_et<_bz_typename BZ_BLITZ_SCOPE(asExpr)<Array<T,N> >::T_expr::T_range_result> > 
+inline _bz_ArrayExpr<#name#_et<_bz_typename blitz::asExpr<Array<T,N> >::T_expr::T_range_result> > 
 #name#(Array<T,N>& d1, int dim1, int dim2)				
 { return #name#(d1.wrap(), dim1, dim2); }
 """
@@ -1293,7 +1295,7 @@ os.write("""
 
 */
 
-BZ_NAMESPACE(blitz)
+namespace blitz {
 
 """)
 
@@ -1399,12 +1401,12 @@ BZ_ET_STENCIL_MULTIDIFF("forward22n", 0, 3)
 BZ_ET_STENCIL_MULTIDIFF("forward32n", 0, 4)
 BZ_ET_STENCIL_MULTIDIFF("forward42n", 0, 5)
 
-BZ_ET_STENCIL("Laplacian2D", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-1,-1)", "shape(1,1)")
-BZ_ET_STENCIL("Laplacian3D", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-1,-1,-1)", "shape(1,1,1)")
-BZ_ET_STENCIL("Laplacian2D4", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-2,-2)", "shape(2,2)")
-BZ_ET_STENCIL("Laplacian2D4n", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-2,-2)", "shape(2,2)")
-BZ_ET_STENCIL("Laplacian3D4", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-2,-2,-2)", "shape(2,2,2)")
-BZ_ET_STENCIL("Laplacian3D4n", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-2,-2,-2)", "shape(2,2,2)")
+BZ_ET_STENCIL("Laplacian2D", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-1,-1)", "shape(1,1)")
+BZ_ET_STENCIL("Laplacian3D", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-1,-1,-1)", "shape(1,1,1)")
+BZ_ET_STENCIL("Laplacian2D4", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-2,-2)", "shape(2,2)")
+BZ_ET_STENCIL("Laplacian2D4n", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-2,-2)", "shape(2,2)")
+BZ_ET_STENCIL("Laplacian3D4", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-2,-2,-2)", "shape(2,2,2)")
+BZ_ET_STENCIL("Laplacian3D4n", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-2,-2,-2)", "shape(2,2,2)")
 
 BZ_ET_STENCILV("grad2D", 2, "shape(-1,-1)", "shape(1,1)")
 BZ_ET_STENCILV("grad2D4", 2, "shape(-2,-2)", "shape(2,2)")
@@ -1428,14 +1430,14 @@ BZ_ET_STENCILM("Jacobian3Dn", 3, "shape(-1,-1,-1)", "shape(1,1,1)")
 BZ_ET_STENCILM("Jacobian3D4", 3, "shape(-2,-2,-2)", "shape(2,2,2)")
 BZ_ET_STENCILM("Jacobian3D4n", 3, "shape(-2,-2,-2)", "shape(2,2,2)")
 
-BZ_ET_STENCIL("curl3D", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-1,-1,-1)", "shape(1,1,1)")
-BZ_ET_STENCIL("curl3Dn", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-1,-1,-1)", "shape(1,1,1)")
-BZ_ET_STENCIL("curl3D4", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-2,-2,-2)", "shape(2,2,2)")
-BZ_ET_STENCIL("curl3D4n", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-2,-2,-2)", "shape(2,2,2)")
-BZ_ET_STENCIL("curl2D", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-1,-1)", "shape(1,1)")
-BZ_ET_STENCIL("curl2Dn", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-1,-1)", "shape(1,1)")
-BZ_ET_STENCIL("curl2D4", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-2,-2)", "shape(2,2)")
-BZ_ET_STENCIL("curl2D4n", "T", "typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype", "shape(-2,-2)", "shape(2,2)")
+BZ_ET_STENCIL("curl3D", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-1,-1,-1)", "shape(1,1,1)")
+BZ_ET_STENCIL("curl3Dn", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-1,-1,-1)", "shape(1,1,1)")
+BZ_ET_STENCIL("curl3D4", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-2,-2,-2)", "shape(2,2,2)")
+BZ_ET_STENCIL("curl3D4n", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-2,-2,-2)", "shape(2,2,2)")
+BZ_ET_STENCIL("curl2D", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-1,-1)", "shape(1,1)")
+BZ_ET_STENCIL("curl2Dn", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-1,-1)", "shape(1,1)")
+BZ_ET_STENCIL("curl2D4", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-2,-2)", "shape(2,2)")
+BZ_ET_STENCIL("curl2D4n", "T", "typename blitz::asExpr<T1>::T_expr::T_numtype", "shape(-2,-2)", "shape(2,2)")
 
 BZ_ET_STENCIL_SCA("div2D", "shape(-1,-1)", "shape(1,1)")
 BZ_ET_STENCIL_SCA("div2Dn", "shape(-1,-1)", "shape(1,1)")
@@ -1446,10 +1448,10 @@ BZ_ET_STENCIL_SCA("div3Dn", "shape(-1,-1,-1)", "shape(1,1,1)")
 BZ_ET_STENCIL_SCA("div3D4", "shape(-2,-2,-2)", "shape(2,2,2)")
 
 
-BZ_ET_STENCIL2("div", "double" , "BZ_PROMOTE(typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype, typename BZ_BLITZ_SCOPE(asExpr)<T2>::T_expr::T_numtype)", "shape(-1,-1)", "shape(1,1)")
-BZ_ET_STENCIL2("divn", "double" , "BZ_PROMOTE(typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype, typename BZ_BLITZ_SCOPE(asExpr)<T2>::T_expr::T_numtype)", "shape(-1,-1)", "shape(1,1)")
-BZ_ET_STENCIL2("div4", "double" , "BZ_PROMOTE(typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype, typename BZ_BLITZ_SCOPE(asExpr)<T2>::T_expr::T_numtype)", "shape(-2,-2)", "shape(2,2)")
-BZ_ET_STENCIL2("div4n", "double" , "BZ_PROMOTE(typename BZ_BLITZ_SCOPE(asExpr)<T1>::T_expr::T_numtype, typename BZ_BLITZ_SCOPE(asExpr)<T2>::T_expr::T_numtype)", "shape(-2,-2)", "shape(2,2)")
+BZ_ET_STENCIL2("div", "double" , "BZ_PROMOTE(typename blitz::asExpr<T1>::T_expr::T_numtype, typename blitz::asExpr<T2>::T_expr::T_numtype)", "shape(-1,-1)", "shape(1,1)")
+BZ_ET_STENCIL2("divn", "double" , "BZ_PROMOTE(typename blitz::asExpr<T1>::T_expr::T_numtype, typename blitz::asExpr<T2>::T_expr::T_numtype)", "shape(-1,-1)", "shape(1,1)")
+BZ_ET_STENCIL2("div4", "double" , "BZ_PROMOTE(typename blitz::asExpr<T1>::T_expr::T_numtype, typename blitz::asExpr<T2>::T_expr::T_numtype)", "shape(-2,-2)", "shape(2,2)")
+BZ_ET_STENCIL2("div4n", "double" , "BZ_PROMOTE(typename blitz::asExpr<T1>::T_expr::T_numtype, typename blitz::asExpr<T2>::T_expr::T_numtype)", "shape(-2,-2)", "shape(2,2)")
 
 BZ_ET_STENCIL_DIFF2("mixed22", -1, 1, -1, 1)
 BZ_ET_STENCIL_DIFF2("mixed22n", -1, 1, -1, 1)
@@ -1457,6 +1459,6 @@ BZ_ET_STENCIL_DIFF2("mixed24", -2, 2, -2, 2)
 BZ_ET_STENCIL_DIFF2("mixed24n", -2, 2, -2, 2)
 
 os.write("""
-BZ_NAMESPACE_END
+}
 """)
 os.close()
