@@ -2,7 +2,7 @@
 #include <blitz/array.h>
 
 
-BZ_USING_NAMESPACE(blitz)
+using namespace blitz;
 
 int main() {
   Array<int, 2> A(4);
